@@ -12,6 +12,9 @@ from .base import BaseCommand
 class SelfUncacheCommand(BaseCommand):
     """Remove dephell cache.
     """
+    # because we don't actually use anything from the config
+    find_config = False
+
     @staticmethod
     def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
