@@ -2,9 +2,9 @@
 from ._conda import CondaCloudRepo, CondaGitRepo, CondaRepo
 from ._getter import get_repo
 from ._git.git import GitRepo
-from ._local_single import LocalRepo
+from ._local import LocalRepo
 from ._release import ReleaseRepo
-from ._warehouse import WarehouseBaseRepo, WarehouseSimpleRepo, WarehouseAPIRepo, WarehouseLocalRepo
+from ._warehouse import WarehouseAPIRepo, WarehouseBaseRepo, WarehouseLocalRepo, WarehouseSimpleRepo
 
 
 __all__ = [
